@@ -1,6 +1,6 @@
 // MIT License
 //
-// Copyright (c) 2017-2022 Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2017-2024 Advanced Micro Devices, Inc. All rights reserved.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -20,27 +20,31 @@
 // OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
 
-#include <cstdio>
-#include <cstdlib>
-#include <iostream>
-#include <limits>
-#include <string>
-#include <vector>
-
-// Google Benchmark
-#include "benchmark/benchmark.h"
+#include "benchmark_utils.hpp"
 // CmdParser
 #include "cmdparser.hpp"
-#include "benchmark_utils.hpp"
+
+// Google Benchmark
+#include <benchmark/benchmark.h>
 
 // HIP API
 #include <hip/hip_runtime.h>
 
 // rocPRIM
-#include <rocprim/rocprim.hpp>
+#include <rocprim/block/block_histogram.hpp>
+#include <rocprim/block/block_load_func.hpp>
+#include <rocprim/block/block_store_func.hpp>
+
+#include <iostream>
+#include <limits>
+#include <string>
+#include <vector>
+
+#include <cstdio>
+#include <cstdlib>
 
 #ifndef DEFAULT_N
-const size_t DEFAULT_N = 1024 * 1024 * 128;
+const size_t DEFAULT_BYTES = 1024 * 1024 * 128 * 4;
 #endif
 
 namespace rp = rocprim;
@@ -91,6 +95,10 @@ struct histogram
         for(unsigned int trial = 0; trial < Trials; trial++)
         {
             bhistogram_t().histogram(values, histogram, storage);
+            for(unsigned int k = 0; k < ItemsPerThread; k++)
+            {
+                values[k] = BinSize - 1 - values[k];
+            }
         }
 
         ROCPRIM_UNROLL
@@ -113,8 +121,10 @@ template<
     unsigned int BinSize = BlockSize,
     unsigned int Trials = 100
 >
-void run_benchmark(benchmark::State& state, hipStream_t stream, size_t N)
+void run_benchmark(benchmark::State& state, hipStream_t stream, size_t bytes)
 {
+    // Calculate the number of elements N
+    size_t N = bytes / sizeof(T);
     // Make sure size is a multiple of BlockSize
     constexpr auto items_per_block = BlockSize * ItemsPerThread;
     const auto size = items_per_block * ((N + items_per_block - 1)/items_per_block);
@@ -180,7 +190,7 @@ void run_benchmark(benchmark::State& state, hipStream_t stream, size_t N)
             .c_str(),                                                                      \
         run_benchmark<Benchmark, T, BS, IPT>,                                              \
         stream,                                                                            \
-        size)
+        bytes)
 
 #define BENCHMARK_TYPE(type, block) \
     CREATE_BENCHMARK(type, block, 1), \
@@ -194,7 +204,7 @@ template<class Benchmark>
 void add_benchmarks(std::vector<benchmark::internal::Benchmark*>& benchmarks,
                     const std::string&                            method_name,
                     hipStream_t                                   stream,
-                    size_t                                        size)
+                    size_t                                        bytes)
 {
     std::vector<benchmark::internal::Benchmark*> new_benchmarks =
     {
@@ -211,7 +221,7 @@ void add_benchmarks(std::vector<benchmark::internal::Benchmark*>& benchmarks,
 int main(int argc, char *argv[])
 {
     cli::Parser parser(argc, argv);
-    parser.set_optional<size_t>("size", "size", DEFAULT_N, "number of values");
+    parser.set_optional<size_t>("size", "size", DEFAULT_BYTES, "number of bytes");
     parser.set_optional<int>("trials", "trials", -1, "number of iterations");
     parser.set_optional<std::string>("name_format",
                                      "name_format",
@@ -221,7 +231,7 @@ int main(int argc, char *argv[])
 
     // Parse argv
     benchmark::Initialize(&argc, argv);
-    const size_t size = parser.get<size_t>("size");
+    const size_t bytes = parser.get<size_t>("size");
     const int trials = parser.get<int>("trials");
     bench_naming::set_format(parser.get<std::string>("name_format"));
 
@@ -230,16 +240,16 @@ int main(int argc, char *argv[])
 
     // Benchmark info
     add_common_benchmark_info();
-    benchmark::AddCustomContext("size", std::to_string(size));
+    benchmark::AddCustomContext("bytes", std::to_string(bytes));
 
     // Add benchmarks
     std::vector<benchmark::internal::Benchmark*> benchmarks;
     // using_atomic
     using histogram_a_t = histogram<rocprim::block_histogram_algorithm::using_atomic>;
-    add_benchmarks<histogram_a_t>(benchmarks, "using_atomic", stream, size);
+    add_benchmarks<histogram_a_t>(benchmarks, "using_atomic", stream, bytes);
     // using_sort
     using histogram_s_t = histogram<rocprim::block_histogram_algorithm::using_sort>;
-    add_benchmarks<histogram_s_t>(benchmarks, "using_sort", stream, size);
+    add_benchmarks<histogram_s_t>(benchmarks, "using_sort", stream, bytes);
 
     // Use manual timing
     for(auto& b : benchmarks)
